@@ -1,5 +1,5 @@
 package Mira::Control::Parser::Markup;
-$Mira::Control::Parser::Markup::VERSION = '00.07.42';
+$Mira::Control::Parser::Markup::VERSION = '00.07.43';
 
 use strict;
 use warnings;
@@ -36,6 +36,10 @@ sub markup {
         );
         if ($html =~ m"<body>([\w\W]*)</body>"m) {
             $body = $1;
+            my $markup = Markup::Unified->new();
+            $markup->format($body, 'markdown');
+            $markup->formatted;
+            $body = $markup->{fvalue};
         }
 
     }
